diff MoinMoin/multiconfig.py @ 788:4840926790f5

indexed search: added Xapian support (needs more work), removed Lupy support
author Thomas Waldmann <tw AT waldmann-edv DOT de>
date Sun, 30 Apr 2006 18:12:28 +0200
parents 92faed4fbd76
children 28de47f4ff1a
line wrap: on
line diff
--- a/MoinMoin/multiconfig.py	Sun Apr 30 16:38:35 2006 +0200
+++ b/MoinMoin/multiconfig.py	Sun Apr 30 18:12:28 2006 +0200
@@ -262,7 +262,7 @@
     language_ignore_browser = False # ignore browser settings, use language_default
                                     # or user prefs
 
-    lupy_search = False # disabled until lupy is finished
+    xapian_search = False # disabled until xapian is finished
 
     mail_login = None # or "user pwd" if you need to use SMTP AUTH
     mail_sendmail = None # "/usr/sbin/sendmail -t -i" to not use SMTP, but sendmail
@@ -505,8 +505,8 @@
         self.navi_bar = [elem % self for elem in self.navi_bar]
         self.backup_exclude = [elem % self for elem in self.backup_exclude]
 
-        # list to cache lupy searcher objects
-        self.lupy_searchers = []
+        # list to cache xapian searcher objects
+        self.xapian_searchers = []
 
         # check if mail is possible and set flag:
         self.mail_enabled = (self.mail_smarthost is not None or self.mail_sendmail is not None) and self.mail_from